/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.context.guice;

import com.google.inject.Injector;
import net.craftforge.essential.context.Application;

import javax.inject.Inject;

/**
 * A guice application provides access to the Guice
 * dependency injection framework.
 *
 * @author Christian Bick
 * @since 26.12.11
 */
public class GuiceApplication implements Application {

    private Injector injector;

    @Inject
    public void GuiceApplication (Injector injector)  {
        this.injector = injector;
    }

    /**
     * {@inheritDoc}
     *
     * <p>
     *     Creates the instance using Guices's injector so
     *     the provided instance is injected also.
     * </p>
     */
    public Object provideInstance(Class<?> clazz) {
        return injector.getInstance(clazz);
    }
}
