/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.context.guice;

import com.google.inject.AbstractModule;
import com.google.inject.servlet.RequestScoped;
import net.craftforge.essential.context.Application;
import net.craftforge.essential.context.Context;
import net.craftforge.essential.context.Request;
import net.craftforge.essential.context.Response;
import net.craftforge.essential.context.servlet.ServletWebContext;
import net.craftforge.essential.context.servlet.ServletWebRequest;
import net.craftforge.essential.context.servlet.ServletWebResponse;

import javax.inject.Singleton;

/**
 * A Guice context module provides an injection configuration
 * for context class related injection.
 *
 * @author Christian Bick
 * @since 26.12.11
 */
public class GuiceContextModule extends AbstractModule {

    /**
     * Configures the module for request and context injection.
     */
    @Override
    protected void configure() {
        bind(Application.class)
                .to(GuiceApplication.class)
                .in(Singleton.class);
        bind(Context.class)
                .to(ServletWebContext.class)
                .in(RequestScoped.class);
        bind(Request.class)
                .to(ServletWebRequest.class)
                .in(RequestScoped.class);
        bind(Response.class)
                .to(ServletWebResponse.class)
                .in(RequestScoped.class);
    }
}
