/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.context.guice;

import com.google.inject.AbstractModule;
import com.google.inject.servlet.RequestScoped;
import net.craftforge.essential.controller.Controller;
import net.craftforge.essential.controller.ControllerConfiguration;
import net.craftforge.essential.controller.allocation.ResourceTree;
import net.craftforge.essential.controller.injection.*;
import net.craftforge.essential.controller.managers.DocumentationManager;
import net.craftforge.essential.controller.managers.ResourceManager;
import net.craftforge.essential.controller.phases.*;
import net.craftforge.essential.controller.phases.flow.DefaultPhaseFlow;
import net.craftforge.essential.controller.phases.flow.PhaseFlow;
import net.craftforge.essential.controller.resolvers.*;
import net.craftforge.essential.core.resolvers.*;

import java.io.InputStream;

/**
 * A Guice controller module provides configuration for
 * controller class related injections.
 *
 * @author Christian Bick
 * @since 28.11.11
 */
public class GuiceControllerModule extends AbstractModule {

    /**
     * Configures the module for controller injection.
     */
    @Override
    protected void configure() {
        bind(ResourceTree.class)
                .toProvider(ResourceTreeProvider.class)
                .in(RequestScoped.class);
        bind(ResourceManager.class)
                .in(RequestScoped.class);
        bind(DocumentationManager.class)
                .in(RequestScoped.class);

        bind(Controller.class)
                .in(RequestScoped.class);
        bind(ControllerConfiguration.class)
                .in(RequestScoped.class);
        bind(PhaseFlow.class)
                .to(DefaultPhaseFlow.class)
                .in(RequestScoped.class);

        bind(InputStream.class)
                .toProvider(RequestBodyProvider.class)
                .in(RequestScoped.class);
        bind(QueryParamMap.class)
                .toProvider(QueryParameterProvider.class)
                .in(RequestScoped.class);
        bind(PathParamMap.class)
                .toProvider(PathParameterProvider.class)
                .in(RequestScoped.class);
        bind(HeaderMap.class)
                .toProvider(RequestHeaderProvider.class)
                .in(RequestScoped.class);

        bind(InputResolver.class)
                .to(DefaultInputResolver.class)
                .in(RequestScoped.class);
        bind(MethodResolver.class)
                .to(DefaultMethodResolver.class)
                .in(RequestScoped.class);
        bind(UrlResolver.class)
                .to(DefaultUrlResolver.class)
                .in(RequestScoped.class);

        bind(BodyResolver.class)
                .to(DefaultBodyResolver.class)
                .in(RequestScoped.class);
        bind(QueryParamResolver.class)
                .to(DefaultQueryParamResolver.class)
                .in(RequestScoped.class);
        bind(PathParamResolver.class)
                .to(DefaultPathParamResolver.class)
                .in(RequestScoped.class);
        bind(HeaderResolver.class)
                .to(DefaultHeaderResolver.class)
                .in(RequestScoped.class);

        bind(CharsetResolver.class)
                .to(DefaultCharsetResolver.class)
                .in(RequestScoped.class);
        bind(MediaTypeResolver.class)
                .to(DefaultMediaTypeResolver.class)
                .in(RequestScoped.class);

        bind(AllocationPhase.class)
                .in(RequestScoped.class);
        bind(AuthenticationPhase.class)
                .in(RequestScoped.class);
        bind(DocumentationPhase.class)
                .in(RequestScoped.class);
        bind(InvocationPhase.class)
                .in(RequestScoped.class);
        bind(ProductionPhase.class)
                .in(RequestScoped.class);
    }
}
