/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.context.guice;

import com.google.inject.Injector;
import net.craftforge.essential.controller.Controller;
import net.craftforge.essential.controller.ControllerException;
import net.craftforge.essential.core.constants.HttpStatusCode;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.inject.Inject;
import javax.inject.Singleton;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * A Guice servlet forwards a servlet request to the controller
 * for further delegation request processing.
 *
 * @author Christian Bick
 * @since 26.12.11
 */
@Singleton
public class GuiceServlet extends HttpServlet {

    private static Logger LOGGER = LoggerFactory.getLogger(GuiceServlet.class);

    private Injector injector;

    @Inject
    public GuiceServlet(Injector injector) {
        this.injector = injector;
    }

    /**
     * {@inheritDoc}
     *
     * <p>
     *     Forwards the request processing to the controller for all
     *     HTTP requests regardless of used HTTP method.
     * </p>
     */
    @Override
    public void service(HttpServletRequest req, HttpServletResponse resp) {
        try {
            Controller controller = injector.getInstance(Controller.class);
            controller.perform();
        } catch (ControllerException e) {
            resp.setStatus(e.getHttpStatusCode().getCode());
            LOGGER.error("Controller failed to perform request", e);
        } catch (Throwable e) {
            resp.setStatus(HttpStatusCode.InternalServerError.getCode());
            LOGGER.error("Controller failed to perform request", e);
        }
    }

}
